# Script file for converting POSPac output ASCII SBET files into nav files readable by CaliGeo
#
# Author: Ben Taylor
# Date: 05/02/2008
#
# Arguments:
# $1: Input file name
# $2: Output file name
# $3: -del to delete original ASCII sbet file when done (default), -nodel to leave it there

if [ ! $2 ] ; then
	echo "Not enough arguments. Usage: sbet2cali.sh Input_File Output_File [-del|-nodel]"
	exit 1
elif [ $3 ] ; then
	if [ $3 == "-nodel" ] ; then
		NODELETEFILE=true
	elif [ $3 != "-del" ] ; then
		echo "Delete argument unrecognised. Usage: sbet2cali.sh Input_File Output_File [-del|-nodel]"
		exit 1
	fi
fi

TEMPDIR=/tmp #Temp directory location - must exist

#Temporary files
TEMPFILE=${TEMPDIR}/cali_tmp.txt

# First line specifies that first column is GPS time
echo "time = gps" > $2
echo "; TIME(s) LATITUDE(deg) LONGITUDE(deg) ALTITUDE(m) ROLL(deg) PITCH(deg) HEADING(deg)" >> $2

# Trim off first 23 lines - header information not used by CaliGeo
tail -n +24 $1 > $TEMPFILE

# Run AWK script to trim unwanted columns
awk '{ \
	printf "%s %s %s %s %s %s %s\n", $1, $6, $7, $8, $9, $10, $11
	}' $TEMPFILE >> $2
	
# Delete temporary file
rm -f $TEMPFILE
	
# Delete original ASCII sbet file unless user opted not to (don't need it any more)
if [ ! $NODELETEFILE ] ; then
	rm -f $1
fi
